@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import flags
+from . import flags
 
 from .api import Wialon, WialonError
 # Silence potential warnings from static analysis tools:
@@ -9,9 +9,9 @@ assert Wialon
 assert WialonError
 
 __author__ = "Alex Chernetsky chal@gurtam.com"
-__copyright__ = ("Copyright 2013, Gurtam; ",)
+__copyright__ = ("Copyright 2013-2016, Gurtam; ",)
 
-__credits__ = ["Alex Chernetsky", "Aleksey Shmigelski"]
-__version__ = "1.0.6"
+__credits__ = ["Alex Chernetsky", "Aleksey Shmigelski", "Mike Turchunovich"]
+__version__ = "1.1.7"
 
 __all__ = ["Wialon"]
